[PATCH i-g-t] tests/kms_content_protection: Add LIC Type 1 scenario

Suraj Kandpal suraj.kandpal at intel.com
Fri Jan 12 10:33:31 UTC 2024


Currently LIC is done only for type0 content this patch
adds LIC for type1 content too.

Signed-off-by: Suraj Kandpal <suraj.kandpal at intel.com>
---
 tests/kms_content_protection.c | 16 ++++++++++++----
 1 file changed, 12 insertions(+), 4 deletions(-)

diff --git a/tests/kms_content_protection.c b/tests/kms_content_protection.c
index 6d472ee02..38e4143c8 100644
--- a/tests/kms_content_protection.c
+++ b/tests/kms_content_protection.c
@@ -43,8 +43,11 @@
 #include "igt_kmod.h"
 
 /**
  * SUBTEST: lic
  * Description: Test for the integrity of link.
  *
  * SUBTEST: content-type-change
  * Description: Test the content type change when the content protection already
@@ -783,11 +786,16 @@ static const struct {
 	  .cp_tests = CP_DPMS,
 	  .content_type = HDCP_CONTENT_TYPE_0
 	},
-	{ .desc = "Test for the integrity of link.",
-	  .name = "lic",
+	{ .desc = "Test for the integrity of link with type 0 content.",
+	  .name = "lic-type-0",
 	  .cp_tests = CP_LIC,
 	  .content_type = HDCP_CONTENT_TYPE_0,
 	},
+	{ .desc = "Test for the integrity of link with type 1 content",
+	  .name = "lic-type-1",
+	  .cp_tests = CP_LIC,
+	  .content_type = HDCP_CONTENT_TYPE_1,
+	},
 	{ .desc = "Test content protection with content type 1 "
 		  "that can be handled only through HDCP2.2.",
 	  .name = "type1",
@@ -43,8 +43,11 @@
 
 /**
- * SUBTEST: lic
- * Description: Test for the integrity of link.
+ * SUBTEST: lic-type-0
+ * Description: Test for the integrity of link for type 0 content.
+ *
+ * SUBTEST: lic-type-1
+ * Description: Test for the integrity of link for type 1 content.
  *
  * SUBTEST: content-type-change
-- 
2.25.1



More information about the igt-dev mailing list